@@ -61,11 +61,9 @@ class CfnConnectionAlias(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -331,11 +329,9 @@ class CfnWorkspace(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
